@@ -130,7 +130,7 @@ class PytestSplitPlugin(Base):
             )
             self.writer.line(message)
 
-    @hookimpl(tryfirst=True)
+    @hookimpl(trylast=True)
     def pytest_collection_modifyitems(self, config: "Config", items: "List[nodes.Item]") -> None:
         """
         Collect and select the tests we want to run, and deselect the rest.
@@ -216,13 +216,13 @@ class PytestSplitCachePlugin(Base):
 
                     # These ifs be removed after this is solved: # https://github.com/spulec/freezegun/issues/286
                     if test_report.duration < 0:
-                        continue
+                        continue  # pragma: no cover
                     if (
                         test_report.when in ("teardown", "setup")
                         and test_report.duration > STORE_DURATIONS_SETUP_AND_TEARDOWN_THRESHOLD
                     ):
                         # Ignore not legit teardown durations
-                        continue
+                        continue  # pragma: no cover
 
                     # Add test durations to map
                     if test_report.nodeid not in test_durations:
